package com.mg.sdk.demo;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;

import com.mg.usercentersdk.MGSdkPlatform;
import com.mg.usercentersdk.demo.R;
import com.mg.usercentersdk.listener.MGInitListener;
import com.mg.usercentersdk.listener.MGLoginListener;
import com.mg.usercentersdk.listener.MGLogoutListener;
import com.mg.usercentersdk.listener.MGPayListener;

import org.json.JSONException;
import org.json.JSONObject;

public class MainActivity extends FragmentActivity implements OnClickListener {
	private String TAG = "MGAndroidSDK";
	private Activity mActivity;

	private Button LoginButton;
	private Button logoutButton;
	private Button payButton;

	private TextView responseText;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.activity_main);
		mActivity = this;

		LoginButton = (Button) findViewById(R.id.btn_Login);
		logoutButton = (Button) findViewById(R.id.btn_logout);
		payButton = (Button) findViewById(R.id.btn_pay);
		responseText = (TextView) findViewById(R.id.responseText);

		LoginButton.setOnClickListener(this);
		logoutButton.setOnClickListener(this);
		payButton.setOnClickListener(this);



		//初始化
		MGSdkPlatform.getInstance().init(this, new MGInitListener() {

			@Override
			public void onSuccess(String msg) {
				Log.d(TAG, "初始化成功;" + "msg===" + msg);
				responseText.setText("初始化成功;msg===" + msg);
			}

			@Override
			public void onFailed(String msg) {
				Log.d(TAG, "初始化失败;" + "msg===" + msg);
			}

		});
	}

	@Override
	public void onClick(View v) {

		int id = v.getId();
		switch (id) {
			case R.id.btn_Login:
				this.runOnUiThread(new Runnable() {

					@Override
					public void run() {
						MGSdkPlatform.getInstance().login(MainActivity.this, new MGLoginListener() {

							@Override
							public void onSuccess(String msg) {
								Log.d(TAG, "登录成功;" + "msg===" + msg);
								responseText.setText("登录成功;msg===" + msg);
								try {
									JSONObject json = new JSONObject(msg);
									String userId = json.getString("userId"); //用户唯一标识
									String token = json.getString("token");   //验证token
									Log.d(TAG, "userId===" + userId+";token="+token);
								} catch (JSONException e) {
									e.printStackTrace();
								}
							}

							@Override
							public void onFailed(String msg) {
								Log.d(TAG, "登录失败;" + "msg===" + msg);
								responseText.setText("登录失败;msg===" + msg);
							}

						});
					}
				});
				break;

			case R.id.btn_logout:
				this.runOnUiThread(new Runnable() {

					@Override
					public void run() {
						MGSdkPlatform.getInstance().logout(mActivity, new MGLogoutListener() {

							@Override
							public void onSuccess(String msg) {
								Log.d(TAG, "登出成功;" + "msg===" + msg);
								responseText.setText("登出成功;msg===" + msg);
							}

							@Override
							public void onFailed(String msg) {
								Log.d(TAG, "登出失败;" + "msg===" + msg);
								responseText.setText("登出失败;msg===" + msg);
							}

						});
					}
				});
				break;

			case R.id.btn_pay:
				MGSdkPlatform.getInstance().pay(this, "368567787F8A434", "comment", "",
						new MGPayListener() {
							@Override
							public void onSuccess(String msg) {
								Log.d(TAG, "支付成功;" + "msg===" + msg);
								responseText.setText("支付成功,msg:=" + msg);
							}

							@Override
							public void onFailed(String msg) {
								Log.d(TAG, "支付失败;" + "msg===" + msg);
								responseText.setText("支付失败,msg:" + msg);
							}
						});
				break;
		}
	}


	@Override
	public boolean onKeyDown(int keyCode, KeyEvent event) {
		if (keyCode == KeyEvent.KEYCODE_BACK && event.getRepeatCount() == 0) {
			Log.i(TAG, " click back key");
			mActivity.runOnUiThread(new Runnable() {

				@Override
				public void run() {
				}
			});
		}
		return super.onKeyDown(keyCode, event);
	}



	private void ShowDialog(Context context, String text) {
		new AlertDialog.Builder(context).setTitle("提示")//设置对话框标题
				.setMessage(text)//设置显示的内容
				.setPositiveButton("确定", new DialogInterface.OnClickListener() {//添加确定按钮
					@Override
					public void onClick(DialogInterface dialog, int which) {//确定按钮的响应事件
						// TODO Auto-generated method stub
					}
				}).show();//在按键响应事件中显示此对话框
	}

	public void onStart() {
		super.onStart();

		MGSdkPlatform.getInstance().onStart();
	}

	//Activity开始和用户交互的时候调用
	public void onResume() {
		super.onResume();

		MGSdkPlatform.getInstance().onResume();
	}

	//Activity被暂停时调用(一个Activity转到另一个Activity调用)
	public void onPause() {
		super.onPause();

		MGSdkPlatform.getInstance().onPause();
	}

	public void onStop() {
		super.onStop();

		MGSdkPlatform.getInstance().onStop();
	}

	public void onRestart() {
		super.onRestart();

		MGSdkPlatform.getInstance().onRestart();
	}

	@Override
	protected void onNewIntent(Intent intent) {
		super.onNewIntent(intent);

		MGSdkPlatform.getInstance().onNewIntent(intent);
	}

	//Activity被从内存中移除，一般发生在执行finish方法时或者Android回收内存的时候
	public void onDestroy() {
		super.onDestroy();

		MGSdkPlatform.getInstance().onDestroy();
	}

	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);

		MGSdkPlatform.getInstance().onActivityResult(requestCode, resultCode, data);
	}
}
